<a id="base_application.OPTIONS"></a>

## OPTIONS

<a id="base_application.*"></a>

## \*

<a id="base_application.signal"></a>

## signal

<a id="base_application.Path"></a>

## Path

<a id="base_application.install_ctrlc_handler"></a>

#### install\_ctrlc\_handler

```python
def install_ctrlc_handler(app)
```

<a id="base_application.install_app_info"></a>

#### install\_app\_info

```python
def install_app_info(app)
```

<a id="base_application.BaseApplication"></a>

## BaseApplication Objects

```python
class BaseApplication(QApplication)
```

<a id="base_application.BaseApplication.__init__"></a>

#### \_\_init\_\_

```python
def __init__(*args, register_ctrlc_handler=True, **kwargs) -> None
```

